Skip to contents

Creates a diagnostic rule that evaluates whether a data cube contains a records with high coordinate uncertainty. The rule counts the number of records (rows) in the cube where the minimal coordinate uncertainty is larger than the resolution of the grid, and compares it to a threshold to determine the severity level.

Usage

rule_spatial_max_uncertainty(
  thresholds = c(ok = 0, note = 1, important = 3, very_important = 5)
)

Arguments

thresholds

Named numeric vector with severity thresholds: ok, note, important, very_important. Defaults are used if not provided.

Value

An object of class cube_rule.