Spatial minimum grid cells diagnostic rule
Source:R/cube_diagnostics_rules.R
rule_spatial_min_cells.RdCreates a diagnostic rule that evaluates whether a data cube contains a sufficient number of spatial observations (grid cells). The rule counts the number of unique grid cells present in the cube and compares it to a threshold to determine the severity level.
Usage
rule_spatial_min_cells(
thresholds = c(ok = 5, note = 3, important = 0, very_important = NULL)
)