Displays a human-readable summary of data cube diagnostics produced by
diagnose_cube(). Each diagnostic metric is shown with a severity flag,
the metric name, and a short explanatory message.
Usage
# S3 method for class 'cube_diagnostics'
print(x, filter_summary = "ok", sort_summary = NA, ...)Arguments
- x
A
cube_diagnosticsobject returned bydiagnose_cube().- filter_summary
Filter the summary output based on a minimum severity level. Default, all levels are shown:
filter_summary = "ok".- sort_summary
Sort the summary output based on severity level. Options are descending (
"desc"), ascending ("asc") or no sorting (NA, default).- ...
Additional arguments passed to other methods (currently unused).
Details
Severity levels are indicated using coloured symbols:
green ball: ok
yellow ball: note
orange ball: important
red ball: very important
See also
Other diagnostic_methods:
plot.cube_diagnostics(),
summary.cube_diagnostics()