Minimum total number of observations diagnostic rule
Source:R/cube_diagnostics_rules.R
rule_obs_min_total.RdCreates a diagnostic rule that evaluates whether a data cube contains a sufficient number of total observations, using a named vector of thresholds for severity classification.
Usage
rule_obs_min_total(
thresholds = c(ok = 40, note = 30, important = 20, very_important = 0)
)