Creates a diagnostic rule that evaluates whether a data cube contains a sufficient number of taxonomical observations (taxa). The rule counts the number of unique taxa present in the cube and compares it to a threshold to determine the severity level.
Usage
rule_taxon_min_taxa(
thresholds = c(ok = 5, note = 3, important = 0, very_important = NULL)
)