Temporal minimum years diagnostic rule
Source:R/cube_diagnostics_rules.R
rule_temporal_min_years.RdCreates a diagnostic rule that evaluates whether a data cube contains a sufficient number of temporal observations (years). The rule counts the number of unique years present in the cube and compares it to a threshold to determine the severity level.
Usage
rule_temporal_min_years(
thresholds = c(ok = 5, note = 3, important = 0, very_important = NULL)
)